OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Şu kullanıcılara posta gönderilemedi: %s",
    "Preparing update" : "Güncelleme hazırlanıyor",
    "Turned on maintenance mode" : "Bakım kipi etkinleştirildi",
    "Turned off maintenance mode" : "Bakım kipi kapatıldı",
    "Maintenance mode is kept active" : "Bakım kipi etkin tutuldu",
    "Updating database schema" : "Veritabanı şeması güncelleniyor",
    "Updated database" : "Veritabanı güncellendi",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Veritabanı şeması güncellenebilirliği denetleniyor (Veritabanının büyüklüğüne bağlı olarak uzun sürebilir)",
    "Checked database schema update" : "Veritabanı şema güncellemesi denetlendi",
    "Checking updates of apps" : "Uygulamaların güncellemeleri denetleniyor",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "%s için veritabanı güncellenebilirliği denetleniyor (Veritabanının büyüklüğüne bağlı olarak uzun sürebilir)",
    "Checked database schema update for apps" : "Uygulamalar için veritabanı şema güncellemesi denetlendi",
    "Updated \"%s\" to %s" : "\"%s\", %s sürümüne güncellendi",
    "Repair warning: " : "Onarım uyarısı:",
    "Repair error: " : "Onarım hatası:",
    "Set log level to debug" : "Günlük seviyesini hata ayıklama olarak ayarla",
    "Reset log level" : "Günlük seviyesini sıfırla",
    "Starting code integrity check" : "Kod bütünlük sınaması başlatılıyor",
    "Finished code integrity check" : "Kod bütünlük sınaması bitti",
    "%s (3rdparty)" : "%s (3. parti)",
    "%s (incompatible)" : "%s (uyumsuz)",
    "Following apps have been disabled: %s" : "Aşağıdaki uygulamalar devre dışı bırakıldı: %s",
    "Already up to date" : "Zaten güncel",
    "Please select a file." : "Lütfen bir dosya seçin.",
    "File is too big" : "Dosya çok büyük",
    "Invalid file provided" : "Geçersiz dosya sağlandı",
    "No image or file provided" : "Resim veya dosya belirtilmedi",
    "Unknown filetype" : "Bilinmeyen dosya türü",
    "Invalid image" : "Geçersiz resim",
    "An error occurred. Please contact your admin." : "Bir hata oluştu. Lütfen yöneticinize başvurun.",
    "No temporary profile picture available, try again" : "Kullanılabilir geçici profil resmi yok, tekrar deneyin",
    "No crop data provided" : "Kesme verisi sağlanmamış",
    "No valid crop data provided" : "Geçerli kırpma verisi sağlanmadı",
    "Crop is not square" : "Kırpma kare değil",
    "Couldn't reset password because the token is invalid" : "Belirteç geçersiz olduğundan parola sıfırlanamadı",
    "Couldn't reset password because the token is expired" : "Jeton zaman aşımına uğradığından parola sıfırlanamadı",
    "Couldn't send reset email. Please make sure your username is correct." : "Sıfırlama e-postası gönderilemedi. Lütfen kullanıcı adınızın doğru olduğundan emin olun.",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Sıfırlama e-postası, bu kullanıcı için bir e-posta adresi olmadığından gönderilemedi. Lütfen yöneticiniz ile iletişime geçin.",
    "%s password reset" : "%s parola sıfırlama",
    "Couldn't send reset email. Please contact your administrator." : "Sıfırlama e-postası gönderilemedi. Lütfen yöneticiniz ile iletişime geçin.",
    "Sunday" : "Pazar",
    "Monday" : "Pazartesi",
    "Tuesday" : "Salı",
    "Wednesday" : "Çarşamba",
    "Thursday" : "Perşembe",
    "Friday" : "Cuma",
    "Saturday" : "Cumartesi",
    "Sun." : "Paz.",
    "Mon." : "Pzt.",
    "Tue." : "Sal.",
    "Wed." : "Çar.",
    "Thu." : "Per.",
    "Fri." : "Cum.",
    "Sat." : "Cmt.",
    "Su" : "Pa",
    "Mo" : "Pt",
    "Tu" : "Sa",
    "We" : "Ça",
    "Th" : "Pe",
    "Fr" : "Cu",
    "Sa" : "Ct",
    "January" : "Ocak",
    "February" : "Şubat",
    "March" : "Mart",
    "April" : "Nisan",
    "May" : "Mayıs",
    "June" : "Haziran",
    "July" : "Temmuz",
    "August" : "Ağustos",
    "September" : "Eylül",
    "October" : "Ekim",
    "November" : "Kasım",
    "December" : "Aralık",
    "Jan." : "Oca.",
    "Feb." : "Şbt.",
    "Mar." : "Mar.",
    "Apr." : "Nis",
    "May." : "May.",
    "Jun." : "Haz.",
    "Jul." : "Tem.",
    "Aug." : "Ağu.",
    "Sep." : "Eyl.",
    "Oct." : "Eki.",
    "Nov." : "Kas.",
    "Dec." : "Ara.",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Kod bütünlük sınamasında sorunlar oluştu. Daha fazla bilgi…</a>",
    "Settings" : "Ayarlar",
    "Saving..." : "Kaydediliyor...",
    "Dismiss" : "İptal et",
    "seconds ago" : "saniyeler önce",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Parolanızı değiştirme bağlantısı e-posta adresinize gönderildi. Makul bir süre içerisinde almadıysanız spam/gereksiz klasörlerini kontrol ediniz.<br>Bu konumlarda da yoksa yerel sistem yöneticinize sorunuz.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Dosyalarınız şifrelenmiş. Kurtarma anahtarını etkinleştirmemişseniz, parola sıfırlama işleminden sonra verilerinize erişmeniz imkansız olacak.<br />Ne yaptığınızdan emin değilseniz, devam etmeden önce sistem yöneticiniz ile iletişime geçin.<br />Gerçekten devam etmek istiyor musunuz?",
    "I know what I'm doing" : "Ne yaptığımı biliyorum",
    "Password can not be changed. Please contact your administrator." : "Parola değiştirilemedi. Lütfen yöneticiniz ile iletişime geçin.",
    "No" : "Hayır",
    "Yes" : "Evet",
    "Choose" : "Seç",
    "Error loading file picker template: {error}" : "Dosya seçici şablonu yüklenirken hata: {error}",
    "Ok" : "Tamam",
    "Error loading message template: {error}" : "İleti şablonu yüklenirken hata: {error}",
    "read-only" : "salt okunur",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} dosya çakışması","{count} dosya çakışması"],
    "One file conflict" : "Bir dosya çakışması",
    "New Files" : "Yeni Dosyalar",
    "Already existing files" : "Zaten mevcut olan dosyalar",
    "Which files do you want to keep?" : "Hangi dosyaları saklamak istiyorsunuz?",
    "If you select both versions, the copied file will have a number added to its name." : "İki sürümü de seçerseniz, kopyalanan dosyanın ismine bir sayı ilave edilecektir.",
    "Cancel" : "İptal",
    "Continue" : "Devam et",
    "(all selected)" : "(tümü seçildi)",
    "({count} selected)" : "({count} seçildi)",
    "Error loading file exists template" : "Dosya mevcut şablonu yüklenirken hata",
    "Very weak password" : "Çok güçsüz parola",
    "Weak password" : "Güçsüz parola",
    "So-so password" : "Normal parola",
    "Good password" : "İyi parola",
    "Strong password" : "Güçlü parola",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Web sunucunuz dosya transferi için düzgün bir şekilde yapılandırılmamış. WevDAV arabirimini sorunlu gözüküyor.",
    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Web sunucunuz \"{url}\" çözümlemesini yapmak üzere doğru yapılandırılmaış.  Daha fazla bilgi <a href=\"{docLink}\">belgelendirmemizde</a> bulunabilir.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Bu sunucunun çalışan bir İnternet bağlantısı yok. Bu, harici depolama alanı bağlama, güncelleştirme bildirimleri veya üçüncü parti uygulama kurma gibi bazı özellikler çalışmayacak demektir. Uzak dosyalara erişim ve e-posta ile bildirim gönderme de çalışmayacaktır. Eğer bu özelliklerin tamamını kullanmak istiyorsanız, sunucu için İnternet bağlantısını etkinleştirmenizi öneriyoruz.",
    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Hafıza önbelleği ayarlanmamış. Performansın artması için mümkünse lütfen bir memcache ayarlayın. Detaylı bilgiye <a  target=\"_blank\" href=\"{docLink}\">belgelendirmemizden</a> ulaşabilirsiniz.",
    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Güvenlik sebepleri ile şiddetle kaçınılması gereken /dev/urandom PHP tarafından okunamıyor. Daha fazla bilgi <a  target=\"_blank\" href=\"{docLink}\">belgelendirmemizde</a> bulunabilir.",
    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "Kullandığınız PHP sürümü ({version}) artık <a  target=\"_blank\" href=\"{phpLink}\">PHP tarafından desteklenmiyor</a>. PHP tarafından sağlanan performans ve güvenlik güncellemelerinden faydalanmak için PHP sürümünüzü güncellemenizi öneririz.",
    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Ters vekil sunucu başlık yapılandırması hatalı veya ownCloud'a güvenilen bir vekil sunucusundan erişiyorsunuz. ownCloud'a güvenilen bir vekil sunucusundan erişmiyorsanız bu bir güvenlik problemidir ve bir saldırganın IP adresinizi taklit etmesine izin verebilir. Ayrıntılı bilgiyi <a  target=\"_blank\" href=\"{docLink}\">belgelendirmemizde</a> bulabilirsiniz.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached ayrılmış önbellek olarak yapılandırıldı, ancak yanlış PHP modülü \"memcache\" olarak yüklendi. \\OC\\Memcache\\Memcached sadece \"memcached\" olarak desteklenir, \"memcache\" olarak kullanamazsınız.  <a  target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a> linkine bakınız.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Bazı dosyalar bütünleme sınamasından geçemedi. Bu sorunu çözmek için daha fazla bilgi <a target=\"_blank\" href=\"{docLink}\">belgelendirmemizde</a> bulunabilir. (<a href=\"{codeIntegrityDownloadEndpoint}\">Geçersiz dosyaların listesi…</a> / <a href=\"{rescanEndpoint}\">Yeniden tara…</a>)",
    "Error occurred while checking server setup" : "Sunucu yapılandırması denetlenirken hata oluştu",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "data dizininiz ve dosyalarınız büyük ihtimalle İnternet üzerinden erişilebilir. .htaccess dosyası çalışmıyor. Web sunucunuzu yapılandırarak data dizinine erişimi kapatmanızı veya data dizinini web sunucu belge dizini dışına almanızı şiddetle tavsiye ederiz.",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "\"{header}\" HTTP başlığı \"{expected}\" ile eşleşmek üzere yapılandırılmamış. Bu muhtemel bir güvenlik veya gizlilik riski olduğundan bu ayarı düzeltmenizi öneririz.",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Bu siteye HTTP aracılığıyla erişiyorsunuz. Sunucunuzu <a href=\"{docUrl}\">güvenlik ipuçlarımızda</a> gösterildiği şekilde HTTPS kullanımını zorlamak üzere yapılandırmanızı şiddetle öneririz.",
    "Shared" : "Paylaşılan",
    "Shared with {recipients}" : "{recipients} ile paylaşılmış",
    "Error" : "Hata",
    "Error while sharing" : "Paylaşım sırasında hata",
    "Error while unsharing" : "Paylaşım iptal edilirken hata",
    "Error setting expiration date" : "Son kullanma tarihi ayarlama hatası",
    "The public link will expire no later than {days} days after it is created" : "Herkese açık bağlantı, oluşturulduktan en geç {days} gün sonra sona erecek",
    "Set expiration date" : "Son kullanma tarihini ayarla",
    "Expiration" : "Bitiş",
    "Expiration date" : "Son kullanım tarihi",
    "Choose a password for the public link" : "Herkese açık bağlantı için bir parola seçin",
    "Sending ..." : "Gönderiliyor...",
    "Email sent" : "E-posta gönderildi",
    "Resharing is not allowed" : "Tekrar paylaşmaya izin verilmiyor",
    "Share link" : "Paylaşma bağlantısı",
    "Link" : "Bağlantı",
    "Password protect" : "Parola koruması",
    "Password" : "Parola",
    "Allow editing" : "Düzenlemeye izin ver",
    "Email link to person" : "Bağlantıyı e-posta ile gönder",
    "Send" : "Gönder",
    "Shared with you and the group {group} by {owner}" : "{owner} tarafından sizinle ve {group} ile paylaştırılmış",
    "Shared with you by {owner}" : "{owner} tarafından sizinle paylaşıldı",
    "group" : "grup",
    "remote" : "uzak",
    "notify by email" : "e-posta ile bildir",
    "Unshare" : "Paylaşmayı Kaldır",
    "can share" : "paylaşabilir",
    "can edit" : "düzenleyebilir",
    "create" : "oluştur",
    "change" : "değiştir",
    "delete" : "sil",
    "access control" : "erişim kontrolü",
    "Could not unshare" : "Paylaşım kaldırılamadı",
    "Share details could not be loaded for this item." : "Bu öge için paylaşma ayrıntıları yüklenemedi.",
    "No users or groups found for {search}" : "{search} için kullanıcı veya grup bulunamadı",
    "An error occured. Please try again" : "Bir hata oluştu. Lütfen yeniden deneyin",
    "Share" : "Paylaş",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "kullanıcı@example.com/owncloud şeklinde diğer ownCloud kullanan diğer kullanıcılarla paylaş",
    "Share with users or groups …" : "Kullanıcı ve gruplarla paylaş...",
    "Share with users, groups or remote users …" : "Kullanıcılar, gruplar veya uzak kullanıcılarla paylaş ...",
    "Error removing share" : "Paylaşım kaldırılırken hata",
    "Warning" : "Uyarı",
    "Error while sending notification" : "Bildirim gönderilirken hata",
    "Non-existing tag #{tag}" : "Mevcut olmayan etiket #{tag}",
    "not assignable" : "atanamaz",
    "invisible" : "görünmez",
    "({scope})" : "({scope})",
    "Delete" : "Sil",
    "Rename" : "Yeniden adlandır",
    "The object type is not specified." : "Nesne türü belirtilmemiş.",
    "Enter new" : "Yeni girin",
    "Add" : "Ekle",
    "Edit tags" : "Etiketleri düzenle",
    "Error loading dialog template: {error}" : "İletişim şablonu yüklenirken hata: {error}",
    "No tags selected for deletion." : "Silmek için bir etiket seçilmedi.",
    "unknown text" : "bilinmeyen metin",
    "Hello world!" : "Merhaba dünya!",
    "sunny" : "güneşli",
    "Hello {name}, the weather is {weather}" : "Merhaba {name}, hava durumu {weather}",
    "Hello {name}" : "Merhaba {name}",
    "_download %n file_::_download %n files_" : ["%n dosya indir","%n dosya indir"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Güncelleme yapılıyor, sayfadan ayrılmak bazı işlemleri kesebilir.",
    "Updating {productName} to version {version}, this may take a while." : "{productName}, {version} sürümüne güncelleniyor, bu biraz zaman alabilir.",
    "An error occurred." : "Bir hata oluştu",
    "Please reload the page." : "Lütfen sayfayı yeniden yükleyin.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Güncelleme başarısız oldu. Daha fazla bilgi için bu sorunu kapsayan <a href=\"{url}\">forum gönderimize</a> bakın.",
    "The update was unsuccessful. " : "Güncelleştirme başarısız.",
    "The update was successful. There were warnings." : "Güncelleme başarılı. Uyarılar mevcut.",
    "The update was successful. Redirecting you to ownCloud now." : "Güncelleme başarılı. Şimdi ownCloud'a yönlendiriliyorsunuz.",
    "Searching other places" : "Diğer konumlarda aranıyor",
    "No search results in other folders" : "Diğer klasörlerde arama sonucu yok",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["Diğer klasörlerde {count} arama sonucu","Diğer bir klasörde {count} arama sonucu"],
    "Personal" : "Kişisel",
    "Users" : "Kullanıcılar",
    "Apps" : "Uygulamalar",
    "Admin" : "Yönetici",
    "Help" : "Yardım",
    "Error loading tags" : "Etiketler yüklenirken hata",
    "Tag already exists" : "Etiket zaten mevcut",
    "Error deleting tag(s)" : "Etiket(ler) silinirken hata",
    "Error tagging" : "Etiketleme hatası",
    "Error untagging" : "Etiket kaldırma hatası",
    "Error favoriting" : "Beğenilirken hata",
    "Error unfavoriting" : "Beğeniden kaldırılırken hata",
    "Access forbidden" : "Erişim yasak",
    "File not found" : "Dosya bulunamadı",
    "The specified document has not been found on the server." : "Belirtilen dosya sunucuda bulunamadı.",
    "You can click here to return to %s." : "%s ana sayfasına dönmek için buraya tıklayabilirsiniz.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Merhaba,\n\nSadece %s sizinle %s paylaşımını yaptığını bildiriyoruz.\nBuradan bakabilirsiniz: %s\n\n",
    "The share will expire on %s." : "Bu paylaşım %s tarihinde sona erecek.",
    "Cheers!" : "Hoşça kalın!",
    "Internal Server Error" : "Dahili Sunucu Hatası",
    "The server encountered an internal error and was unable to complete your request." : "Sunucu dahili bir hatayla karşılaştı ve isteğinizi tamamlayamadı.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Eğer bu hata birden çok kez oluştuysa, lütfen sunucu yöneticisine aşağıdaki teknik ayrıntılar ile birlikte iletişime geçin.",
    "More details can be found in the server log." : "Daha fazla ayrıntı sunucu günlüğünde bulanabilir.",
    "Technical details" : "Teknik ayrıntılar",
    "Remote Address: %s" : "Uzak Adres: %s",
    "Request ID: %s" : "İstek Kimliği: %s",
    "Type: %s" : "Tür: %s",
    "Code: %s" : "Kod: %s",
    "Message: %s" : "Mesaj: %s",
    "File: %s" : "Dosya: %s",
    "Line: %s" : "Satır: %s",
    "Trace" : "İz",
    "Security warning" : "Güvenlik uyarısı",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Veri klasörünüz ve dosyalarınız .htaccess dosyası çalışmadığı için İnternet'ten erişime açık.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Sunucunuzu nasıl ayarlayacağınıza dair bilgi için, lütfen <a href=\"%s\" target=\"_blank\">belgelendirme sayfasını</a> ziyaret edin.",
    "Create an <strong>admin account</strong>" : "Bir <strong>yönetici hesabı</strong> oluşturun",
    "Username" : "Kullanıcı Adı",
    "Storage & database" : "Depolama ve veritabanı",
    "Data folder" : "Veri klasörü",
    "Configure the database" : "Veritabanını yapılandır",
    "Only %s is available." : "Sadece %s kullanılabilir.",
    "Install and activate additional PHP modules to choose other database types." : "Diğer veritabanı türlerini seçebilmek için ek PHP modüllerini kurun ve etkinleştirin.",
    "For more details check out the documentation." : "Daha fazla bilgi için belgelendirmeye bakın.",
    "Database user" : "Veritabanı kullanıcı adı",
    "Database password" : "Veritabanı parolası",
    "Database name" : "Veritabanı adı",
    "Database tablespace" : "Veritabanı tablo alanı",
    "Database host" : "Veritabanı sunucusu",
    "Performance warning" : "Performans uyarısı",
    "SQLite will be used as database." : "Veritabanı olarak SQLite kullanılacak.",
    "For larger installations we recommend to choose a different database backend." : "Daha büyük kurulumlar için farklı bir veritabanı arka ucu seçmenizi öneriyoruz",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Özellikle dosya eşitleme için masaüstü istemcisi kullanılırken SQLite kullanımı önerilmez.",
    "Finish setup" : "Kurulumu tamamla",
    "Finishing …" : "Tamamlanıyor ...",
    "Need help?" : "Yardım mı lazım?",
    "See the documentation" : "Belgelendirmeye bak",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Merhaba, <br><br>%s kullanıcısının sizinle <strong>%s</strong> paylaşımında bulunduğunu bildirmek istedik.<br><a href=\"%s\">Paylaşımı gör!</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Bu uygulama düzgün çalışabilmesi için JavaScript gerektirir. Lütfen {linkstart}JavaScript'i etkinleştirin{linkend} ve sayfayı yeniden yükleyin.",
    "Log out" : "Çıkış yap",
    "Search" : "Ara",
    "Server side authentication failed!" : "Sunucu taraflı yetkilendirme başarısız!",
    "Please contact your administrator." : "Lütfen sistem yöneticiniz ile iletişime geçin.",
    "An internal error occured." : "Dahili bir hata oluştu.",
    "Please try again or contact your administrator." : "Lütfen yeniden deneyin veya yöneticinizle iletişim kurun.",
    "Log in" : "Giriş yap",
    "Wrong password. Reset it?" : "Hatalı parola. Sıfırlansın mı?",
    "Wrong password." : "Hatalı parola.",
    "Stay logged in" : "Bağlı kal",
    "Alternative Logins" : "Alternatif Girişler",
    "Use the following link to reset your password: {link}" : "Parolanızı sıfırlamak için bu bağlantıyı kullanın: {link}",
    "New password" : "Yeni parola",
    "New Password" : "Yeni Parola",
    "Reset password" : "Parolayı sıfırla",
    "This ownCloud instance is currently in single user mode." : "Bu ownCloud örneği şu anda tek kullanıcı kipinde.",
    "This means only administrators can use the instance." : "Bu, örneği sadece yöneticiler kullanabilir demektir.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Eğer bu ileti görünmeye devam ederse veya beklenmedik şekilde ortaya çıkmışsa sistem yöneticinizle iletişime geçin.",
    "Thank you for your patience." : "Sabrınız için teşekkür ederiz.",
    "You are accessing the server from an untrusted domain." : "Sunucuya güvenilmeyen bir alan adından ulaşıyorsunuz.",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Lütfen yöneticiniz ile iletişime geçin. Eğer bu örneğin bir yöneticisi iseniz, config/config.php dosyası içerisindeki \"trusted_domain\" ayarını yapılandırın. Bu yapılandırmanın bir örneği config/config.sample.php dosyasında verilmiştir.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Yapılandırmanıza bağlı olarak, bir yönetici olarak bu alan adına güvenmek için aşağıdaki düğmeyi de kullanabilirsiniz.",
    "Add \"%s\" as trusted domain" : "\"%s\" alan adını güvenilir olarak ekle",
    "App update required" : "Uygulama güncellemesi gerekli",
    "%s will be updated to version %s" : "%s, %s sürümüne güncellenecek",
    "These apps will be updated:" : "Bu uygulamalar güncellenecek:",
    "These incompatible apps will be disabled:" : "Bu uyumsuz uygulamalar devre dışı bırakılacak:",
    "The theme %s has been disabled." : "%s teması devre dışı bırakıldı.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Devam etmeden önce lütfen veritabanının, yapılandırma ve veri klasörlerinin yedeklenmiş olduğundan emin olun.",
    "Start update" : "Güncellemeyi başlat",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Daha büyük kurulumlarda zaman aşımlarının önüne geçmek için, kurulum dizininizden aşağıdaki komutu da çalıştırabilirsiniz:",
    "This %s instance is currently in maintenance mode, which may take a while." : "Bu %s örneği şu anda bakım kipinde, bu biraz zaman alabilir.",
    "This page will refresh itself when the %s instance is available again." : "Bu sayfa, %s örneği tekrar kullanılabilir olduğunda kendini yenileyecektir.",
    "Error loading file picker template: {error}" : "Dosya seçici şablonu yüklenirken hata: {error}",
    "Password can not be changed. Please contact your administrator." : "Parola değiştirilemedi. Lütfen yöneticiniz ile iletişime geçin."
},
"nplurals=2; plural=(n > 1);");
